class Auction < ActiveRecord::Base
  belongs_to :item
  belongs_to :seller, :class_name => "User", :foreign_key => "seller_id"
  has_many :bids
  has_many :bidders, :through => :bids
  belongs_to :winner, :class_name => "User", :foreign_key => "winner_id"
  has_one :highest_bid, :class_name => "Bid",
          :order => "amount DESC"
  
  validates_associated :item

  def current_bid
    h = highest_bid
    return(if h then h.amount else 0 end)
  end

  def highest_bidder
    highest_bid && highest_bid.bidder
  end

  def reserve_met?
    current_bid >= reserve
  end

  def over?
    winner
  end

  def complete
    self.winner = highest_bidder
    save
  end
  
  def next_bid
    current_bid + incr
  end
end
