class User < ActiveRecord::Base
  has_one :contact
  has_many :auctions_bid_in, :through => :bids, :source => "auction", :uniq => true
  has_many :auctions_held, :class_name => "Auction", :foreign_key => "seller_id",
           :dependent => :destroy
  has_many :bids, :foreign_key => "bidder_id", :dependent => :destroy

  has_many :items, :through => :auctions_held, :source => "item",
           :class_name => "Item", :foreign_key => "item_id"

  attr_accessor :password

  def bid_on(auction)
    return false unless can_bid_on?(auction)
    Bid.create(:auction => auction, :bidder => self, :amount => auction.next_bid)
  end

  def whole_name
    w = first_name
    w << " #{middle_name}" if middle_name
    w << " #{last_name}"
  end

  def can_bid_on?(auction)
    return false if auction.over?
    return false if self == auction.seller
    return false if self == auction.highest_bidder && auction.reserve_met?
    return true
  end

  def authorize(password)
    Digest::SHA1.hexdigest(password) == hashed_password
  end
end
