# This is the file config/routes.rb for the auction application.
# The routes here overlap with those in the short cut, but they're
# not all the same; some of the ones in the short cut are intermediate
# examples that aren't actually used in the application.  You will,
# however, find at least one example here of each of the major
# routing techniques discussed in the short cut. 

ActionController::Routing::Routes.draw do |map|
  
# This will give us the full complement of resource routes
# for bids.
  map.resources :bids

# Likewise for sessions.
  map.resources :sessions

# Here, we get the resource routes for auctions, and also a new
# set for bids, with the name prefix "auction_": auction_bid_url,
# new_auction_bid, etc.
  map.resources :auctions do |auction|
    auction.resources :bids, :name_prefix => "auction_"
  end

# Similarly here for bids with the user_prefix.  In addition, we
# get a custom-made member action, in the form of
# retract_user_bid_url(bid).
  map.resources :users do |u|
    u.resources :bids, :name_prefix => "user_",
                       :member => { :retract => :get }
  end

# The top-level route, defaulting to the "index" action.
  map.connect '', :controller => "auctions"

# Another way to do the top-level route -- as a named route.
  map.top '', :controller => "auctions"

# A custom route, giving us access to the history action for an
# auction.
  map.connect 'history/:id',
    :controller => "auctions",
    :action     => "history"

# A simple named route, mapping the static string "profiles" to
# the hard-coded users controller and show action.
  map.profile 'profiles/:id',
    :controller => "users",
    :action => "show"

# Get all the items for a particular year, testing to make sure
# that year has four digits.
  map.connect 'item_year/:year',
    :year => /\d{4}/,
    :controller => "items",
    :action => "item_year"

# Route globbing will put all remaining wildcards into the array
# params[:specs], from which we can pull them in order to conduct
# a search (see app/models/item.rb). 
  map.connect 'items_by/*specs',
    :controller => "items",
    :action     => "specify"

# Some named routes, giving expressive semantics to some functions
# connected with users and sessions.  (There's some overlap here with
# the resource routing, and in "real life" you'd probably want to do
# one or the other.) 
  map.register 'register',
    :controller => "users",
    :action     => "new"

  map.login 'login',
    :controller => "sessions",
    :action     => "new"
      
  map.verify 'authorize',
    :controller => "sessions",
    :action => "create"

# Here we use with_options to constrain a whole set of routes
# to the scope of the "main" controller. 
  map.with_options :controller => "main" do |main|
    main.help '/help', :action => "help"
    main.contact '/contact', :action => "contact"
    main.about '/about', :action => "about"
  end

  # Allow downloading Web Service WSDL as a file with an extension
  # instead of a file named 'wsdl'
  map.connect ':controller/service.wsdl', :action => 'wsdl'

  # Install the default route as the lowest priority.
  map.connect ':controller/:action/:id.:format'
  map.connect ':controller/:action/:id'
end
