require File.dirname(__FILE__) + '/../test_helper'

class NamedRoutesTest < ActionController::IntegrationTest

# Match auction_path(int) to the show action.
  def test_show_route_using_integer
    assert_recognizes({:controller => "auctions", 
                       :action => "show", 
                       :id => "1" }, 
                     auction_path(1))
  end

# Same as the above, but using a specific Auction object, to make sure
# that the id field is gleaned correctly.
  def test_show_route_using_object
    auction = Auction.create
    assert_recognizes({:controller => "auctions",
                       :action => "show",
                       :id => auction.id.to_s },
                     auction_path(auction))
  end

# And a third version of the same test, this time using the hash
# argument syntax. 
  def test_show_route_using_hash
    auction = Auction.create
    assert_recognizes({:controller => "auctions",
                       :action => "show",
                       :id => auction.id.to_s },
                     auction_path(:id => auction))
  end

# Testing the dedicated edit_auction_path route.
  def test_edit_route
    assert_recognizes({:controller => "auctions", :action => "edit", :id => "1" },
      edit_auction_path(1))
  end

# Testing the custom retract route. 
  def test_retract_route
    assert_recognizes({:controller => "bids", :action => "retract", :id => "1", :user_id => "3" },
      user_retract_bid_path(3,1))
  end

# And one in the other direction, to make sure that generation is
# working too.
  def test_generate_retract
    assert_generates(user_retract_bid_path(3,1),
      :controller => "bids", 
      :action => "retract", 
      :id => "1", 
      :user_id => "3"  )
  end
end

